document.getElementById('start-btn').addEventListener('click', startGame);

let score = 0;
let attempts = 5;
let correctIndex = -1;

async function startGame() {
    document.getElementById('start-btn').disabled = true;
    document.getElementById('progress').style.width = '0%';
    document.getElementById('progress').innerText = '生成图片中...';

    // 禁用所有选项按钮
    const optionButtons = document.querySelectorAll('.option');
    optionButtons.forEach(button => button.disabled = true);

    try {
        const progressInterval = simulateProgressBar();
        const response = await fetch('/start_game', {
            method: 'POST'
        });
        const data = await response.json();
        clearInterval(progressInterval);
        correctIndex = data.correct_index;
        document.getElementById('poem-image').src = data.image_url;
        document.getElementById('options-container').innerHTML = '';
        data.options.forEach((option, index) => {
            const button = document.createElement('button');
            button.className = 'option';
            button.dataset.index = index;
            button.innerText = String.fromCharCode(65 + index) + '. ' + option;
            button.addEventListener('click', checkAnswer);
            document.getElementById('options-container').appendChild(button);
        });

    } catch (error) {
        console.error('Error:', error);
    }
}

function simulateProgressBar() {
    let width = 0;
    const interval = setInterval(() => {
        if (width >= 100) {
            clearInterval(interval);
            document.getElementById('progress').innerText = '图片生成完成';
            // 启用所有选项按钮
            const optionButtons = document.querySelectorAll('.option');
            optionButtons.forEach(button => button.disabled = false);
            document.getElementById('start-btn').disabled = false;
        } else {
            width += 5;
            document.getElementById('progress').style.width = width + '%';
        }
    }, 1000);
}


function checkAnswer(event) {
    const userAnswer = event.target.dataset.index;
    fetch('/check_answer', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json'
        },
        body: JSON.stringify({
            answer: userAnswer,
            correct_index: correctIndex
        })
    })
    .then(response => response.json())
    .then(data => {
        if (data.is_correct) {
            score += 20;
        }
        //alert(`${data}`);
        attempts -= 1;
        document.getElementById('score').innerText = score;
        document.getElementById('attempts').innerText = attempts;

        if (attempts > 0) {
            startGame();
        } else {
            alert(`游戏结束，你的得分是: ${score}`);
            document.getElementById('start-btn').disabled = false;
            score = 0;
            attempts = 5;
        }
    });
}